import { ClientParams } from '../core/clientParams';
import { Response } from '../core/response';
import { RequestBody, RequestOptions, RestClient } from '../core/restClient';
export declare class HttpTransportClient implements RestClient {
    private readonly client;
    private readonly params;
    private readonly timeout;
    /**
     * HttpTransport rest client implementation
     * @param {ClientParams} params - Client parameters
     * @see ClientParams
     */
    constructor(params: ClientParams);
    patch(uri: string, body: RequestBody, opts?: RequestOptions): Promise<Response>;
    /**
     * Executes a HTTP GET
     *
     * @return a Promise<Response> instance
     * @param {string} uri - uri to request
     * @param {RequestOptions} opts - optional request configuration
     */
    get(uri: string, opts?: RequestOptions): Promise<Response>;
    /**
     * Executes a HTTP POST
     *
     * @return a Promise<Response> instance
     * @param {string} uri - uri to request
     * @param {RequestBody} body - request body
     * @param {RequestOptions} opts - optional request configuration
     */
    post(uri: string, body: RequestBody, opts?: RequestOptions): Promise<Response>;
    /**
     * Executes a HTTP PUT
     *
     * @return a Promise<Response> instance
     * @param {string} uri - uri to request
     * @param {RequestBody} body - request body
     * @param {RequestOptions} opts - optional request configuration
     */
    put(uri: string, body: RequestBody, opts?: RequestOptions): Promise<Response>;
    /**
     * Executes a HTTP HEAD
     *
     * @return a Promise<Response> instance
     * @param {string} uri - uri to request
     * @param {RequestOptions} opts - optional request configuration
     */
    head(uri: string, opts?: RequestOptions): Promise<Response>;
    /**
     * Executes a HTTP DELETE
     *
     * @return a Promise<Response> instance
     * @param {string} uri - uri to request
     * @param {RequestOptions} opts - optional request configuration
     */
    delete(uri: string, opts?: RequestOptions): Promise<Response>;
    private toResponse;
}
